@@ -1,5 +1,5 @@
 package App::cpm;
-use 5.008_005;
+use 5.008001;
 use strict;
 use warnings;
 use App::cpm::Master;
@@ -18,7 +18,7 @@ use File::Path ();
 use Cwd ();
 use Config;
 
-our $VERSION = '0.299';
+our $VERSION = '0.300';
 
 use constant WIN32 => $^O eq 'MSWin32';
 
@@ -32,6 +32,7 @@ sub new {
         local_lib => "local",
         cpanmetadb => "http://cpanmetadb.plackperl.org/v1.0/",
         mirror => ["http://www.cpan.org/", "http://backpan.perl.org/"],
+        retry => 1,
         %option
     }, $class;
 }
@@ -61,6 +62,7 @@ sub parse_options {
         "man-pages" => \($self->{man_pages}),
         "home=s" => \($self->{home}),
         "with-develop" => \($self->{with_develop}),
+        "retry!" => \($self->{retry}),
     or exit 1;
 
     $self->{local_lib} = $self->maybe_abs($self->{local_lib}) unless $self->{global};
@@ -75,10 +77,9 @@ sub parse_options {
         die "--target-perl option can be used only if perl version >= 5.16.0\n" if $] < 5.016;
         # 5.8 is interpreted as 5.800, fix it
         $target_perl = "v$target_perl" if $target_perl =~ /^5\.[1-9]\d*$/;
-        $self->{target_perl} = App::cpm::version->parse($target_perl)->numify;
-        if ($self->{target_perl} > $]) {
-            die "--target-perl must be lower than your perl version $]\n";
-        }
+        $target_perl = sprintf '%0.6f', App::cpm::version->parse($target_perl)->numify;
+        $target_perl = '5.008' if $target_perl eq '5.008000';
+        $self->{target_perl} = $target_perl;
     }
     if (WIN32 and $self->{workers} != 1) {
         die "The number of workers must be 1 under WIN32 environment.\n";
@@ -193,6 +194,7 @@ sub cmd_install {
         sudo            => $self->{sudo},
         resolver        => $self->generate_resolver,
         man_pages       => $self->{man_pages},
+        retry           => $self->{retry},
         ($self->{global} ? () : (local_lib => $self->{local_lib})),
     );
     my $pipes = Parallel::Pipes->new($self->{workers}, sub {
@@ -303,7 +305,8 @@ sub register_initial_job {
             return 0;
         } elsif (!defined $is_satisfied) {
             my ($req) = grep { $_->{package} eq "perl" } @$requirements;
-            die sprintf "%s requires perl %s, but you have only %s\n", $self->{cpanfile}, $req->{version_range}, $];
+            die sprintf "%s requires perl %s, but you have only %s\n",
+                $self->{cpanfile}, $req->{version_range}, $self->{target_perl} || $];
         } else {
             @package = @need_resolve;
         }
@@ -480,6 +483,22 @@ Just an example:
 
 This shows cpm is 3x faster than cpanm.
 
+=head1 CAVEATS
+
+L<eserte|https://github.com/skaji/cpm/issues/71> reported that
+the parallel feature of cpm yielded a new type of failure for CPAN module installation.
+That is,
+if B<ModuleA> implicitly requires B<ModuleB> in configure/build phase,
+and B<ModuleB> is about to be installed,
+then it may happen that the installation of B<ModuleA> fails.
+
+I can say that it hardly happens especially if you use a new Perl.
+Moreover, for a workaround, cpm automatically retries the installation if it fails.
+
+I hope that
+if almost all CPAN modules are distributed with L<static install enabled|http://blogs.perl.org/users/shoichi_kaji1/2017/03/make-your-cpan-module-static-installable.html>,
+then cpm will parallelize the installation for these CPAN modules safely and we can eliminate this new type of failure completely.
+
 =head1 ROADMAP
 
 If you all find cpm useful,
