@@ -7,7 +7,7 @@ use App::cpm::Job;
 use App::cpm::Logger;
 use Module::Metadata;
 use version;
-our $VERSION = '0.299';
+our $VERSION = '0.300';
 
 sub new {
     my ($class, %option) = @_;
@@ -23,8 +23,8 @@ sub new {
     }, $class;
     if ($self->{target_perl}) {
         require Module::CoreList;
-        if (!exists $Module::CoreList::version{$]}) {
-            die "Module::CoreList does not have your perl $^V entry, abort.\n";
+        if (!exists $Module::CoreList::version{$self->{target_perl}}) {
+            die "Module::CoreList does not have target perl $self->{target_perl} entry, abort.\n";
         }
     }
     $self;
@@ -133,7 +133,8 @@ sub _calculate_jobs {
                 $self->{_fail_install}{$dist->distfile}++ unless $ok;
             } elsif (!defined $is_satisfied) {
                 my ($req) = grep { $_->{package} eq "perl" } @{$dist->configure_requirements};
-                my $msg = sprintf "%s requires perl %s, but you have only %s", $dist->distvname, $req->{version_range}, $];
+                my $msg = sprintf "%s requires perl %s, but you have only %s",
+                    $dist->distvname, $req->{version_range}, $self->{target_perl} || $];
                 $self->{logger}->log($msg);
                 App::cpm::Logger->log(result => "FAIL", message => $msg);
                 $self->{_fail_install}{$dist->distfile}++;
@@ -166,7 +167,8 @@ sub _calculate_jobs {
                 $self->{_fail_install}{$dist->distfile}++ unless $ok;
             } elsif (!defined $is_satisfied) {
                 my ($req) = grep { $_->{package} eq "perl" } @{$dist->requirements};
-                my $msg = sprintf "%s requires perl %s, but you have only %s", $dist->distvname, $req->{version_range}, $];
+                my $msg = sprintf "%s requires perl %s, but you have only %s",
+                    $dist->distvname, $req->{version_range}, $self->{target_perl} || $];
                 $self->{logger}->log($msg);
                 App::cpm::Logger->log(result => "FAIL", message => $msg);
                 $self->{_fail_install}{$dist->distfile}++;
